summaryrefslogtreecommitdiffstats
path: root/sys/dev
diff options
context:
space:
mode:
authorkevlo <kevlo@FreeBSD.org>2007-10-12 06:03:46 +0000
committerkevlo <kevlo@FreeBSD.org>2007-10-12 06:03:46 +0000
commit7a9f1e285b4917d1e77dd6272654278cedc141fd (patch)
tree5d1c0175e9c89b84168bf6dffe130b9dd7ffb477 /sys/dev
parenta7a6cc62cbb4f888b36f438e41119d295a856e55 (diff)
downloadFreeBSD-src-7a9f1e285b4917d1e77dd6272654278cedc141fd.zip
FreeBSD-src-7a9f1e285b4917d1e77dd6272654278cedc141fd.tar.gz
Spelling fix for interupt -> interrupt
Diffstat (limited to 'sys/dev')
-rw-r--r--sys/dev/cm/smc90cx6.c6
-rw-r--r--sys/dev/ctau/if_ct.c2
-rw-r--r--sys/dev/cx/if_cx.c2
-rw-r--r--sys/dev/idt/idt_pci.c2
-rw-r--r--sys/dev/isp/isp_target.c4
-rw-r--r--sys/dev/mpt/mpt.c6
-rw-r--r--sys/dev/my/if_my.c2
-rw-r--r--sys/dev/sio/sio.c2
-rw-r--r--sys/dev/sound/isa/ad1816.c8
-rw-r--r--sys/dev/sound/isa/ad1816.h2
-rw-r--r--sys/dev/sound/pci/atiixp.c2
-rw-r--r--sys/dev/sound/pci/emu10kx.c2
-rw-r--r--sys/dev/sound/pci/envy24.c2
-rw-r--r--sys/dev/sound/pci/envy24ht.c2
-rw-r--r--sys/dev/sound/sbus/cs4231.c2
15 files changed, 23 insertions, 23 deletions
diff --git a/sys/dev/ctau/if_ct.c b/sys/dev/ctau/if_ct.c
index 3769419..25e927a 100644
--- a/sys/dev/ctau/if_ct.c
+++ b/sys/dev/ctau/if_ct.c
@@ -272,7 +272,7 @@ static void ct_led_off (void *arg)
}
/*
- * Activate interupt handler from DDK.
+ * Activate interrupt handler from DDK.
*/
static void ct_intr (void *arg)
{
diff --git a/sys/dev/cx/if_cx.c b/sys/dev/cx/if_cx.c
index b75f23b..34ccd5a 100644
--- a/sys/dev/cx/if_cx.c
+++ b/sys/dev/cx/if_cx.c
@@ -358,7 +358,7 @@ static void cx_led_off (void *arg)
}
/*
- * Activate interupt handler from DDK.
+ * Activate interrupt handler from DDK.
*/
static void cx_intr (void *arg)
{
diff --git a/sys/dev/idt/idt_pci.c b/sys/dev/idt/idt_pci.c
index 07c061d..e446713 100644
--- a/sys/dev/idt/idt_pci.c
+++ b/sys/dev/idt/idt_pci.c
@@ -219,7 +219,7 @@ idt_detach(device_t dev)
idt_device_stop(sc); /* Stop the device */
/*
- * Lock out all device interupts.
+ * Lock out all device interrupts.
*/
DEVICE_LOCK(&sc->iu_cmn);
idt_free(dev);
diff --git a/sys/dev/isp/isp_target.c b/sys/dev/isp/isp_target.c
index 9ad79ab..531f64b 100644
--- a/sys/dev/isp/isp_target.c
+++ b/sys/dev/isp/isp_target.c
@@ -1332,7 +1332,7 @@ isp_handle_ctio(ispsoftc_t *isp, ct_entry_t *ct)
* Bus Device Reset message received or the SCSI Bus has
* been Reset; the firmware has gone to Bus Free.
*
- * The firmware generates an async mailbox interupt to
+ * The firmware generates an async mailbox interrupt to
* notify us of this and returns outstanding CTIOs with this
* status. These CTIOs are handled in that same way as
* CT_ABORTED ones, so just fall through here.
@@ -1486,7 +1486,7 @@ isp_handle_ctio2(ispsoftc_t *isp, ct2_entry_t *ct)
/*
* Target Reset function received.
*
- * The firmware generates an async mailbox interupt to
+ * The firmware generates an async mailbox interrupt to
* notify us of this and returns outstanding CTIOs with this
* status. These CTIOs are handled in that same way as
* CT_ABORTED ones, so just fall through here.
diff --git a/sys/dev/mpt/mpt.c b/sys/dev/mpt/mpt.c
index 2cd6a2f..38fab51 100644
--- a/sys/dev/mpt/mpt.c
+++ b/sys/dev/mpt/mpt.c
@@ -1356,7 +1356,7 @@ mpt_send_handshake_cmd(struct mpt_softc *mpt, size_t len, void *cmd)
len = (len + 3) >> 2;
data32 = cmd;
- /* Clear any left over pending doorbell interupts */
+ /* Clear any left over pending doorbell interrupts */
if (MPT_DB_INTR(mpt_rd_intr(mpt)))
mpt_write(mpt, MPT_OFFSET_INTR_STATUS, 0);
@@ -2095,7 +2095,7 @@ mpt_send_event_request(struct mpt_softc *mpt, int onoff)
}
/*
- * Un-mask the interupts on the chip.
+ * Un-mask the interrupts on the chip.
*/
void
mpt_enable_ints(struct mpt_softc *mpt)
@@ -2105,7 +2105,7 @@ mpt_enable_ints(struct mpt_softc *mpt)
}
/*
- * Mask the interupts on the chip.
+ * Mask the interrupts on the chip.
*/
void
mpt_disable_ints(struct mpt_softc *mpt)
diff --git a/sys/dev/my/if_my.c b/sys/dev/my/if_my.c
index 4cd0781..c94f084 100644
--- a/sys/dev/my/if_my.c
+++ b/sys/dev/my/if_my.c
@@ -1441,7 +1441,7 @@ my_start_locked(struct ifnet * ifp)
/*
* Place the request for the upload interrupt in the last descriptor
* in the chain. This way, if we're chaining several packets at once,
- * we'll only get an interupt once for the whole chain rather than
+ * we'll only get an interrupt once for the whole chain rather than
* once for each packet.
*/
MY_TXCTL(cur_tx) |= MY_TXIC;
diff --git a/sys/dev/sio/sio.c b/sys/dev/sio/sio.c
index 006eefc..04d10ef 100644
--- a/sys/dev/sio/sio.c
+++ b/sys/dev/sio/sio.c
@@ -600,7 +600,7 @@ sioprobe(dev, xrid, rclk, noprobe)
}
/*
- * Enable the interrupt gate and disable device interupts. This
+ * Enable the interrupt gate and disable device interrupts. This
* should leave the device driving the interrupt line low and
* guarantee an edge trigger if an interrupt can be generated.
*/
diff --git a/sys/dev/sound/isa/ad1816.c b/sys/dev/sound/isa/ad1816.c
index d3ece80..4c5ecab 100644
--- a/sys/dev/sound/isa/ad1816.c
+++ b/sys/dev/sound/isa/ad1816.c
@@ -128,22 +128,22 @@ ad1816_intr(void *arg)
unsigned char c, served = 0;
ad1816_lock(ad1816);
- /* get interupt status */
+ /* get interrupt status */
c = io_rd(ad1816, AD1816_INT);
- /* check for stray interupts */
+ /* check for stray interrupts */
if (c & ~(AD1816_INTRCI | AD1816_INTRPI)) {
printf("pcm: stray int (%x)\n", c);
c &= AD1816_INTRCI | AD1816_INTRPI;
}
- /* check for capture interupt */
+ /* check for capture interrupt */
if (sndbuf_runsz(ad1816->rch.buffer) && (c & AD1816_INTRCI)) {
ad1816_unlock(ad1816);
chn_intr(ad1816->rch.channel);
ad1816_lock(ad1816);
served |= AD1816_INTRCI; /* cp served */
}
- /* check for playback interupt */
+ /* check for playback interrupt */
if (sndbuf_runsz(ad1816->pch.buffer) && (c & AD1816_INTRPI)) {
ad1816_unlock(ad1816);
chn_intr(ad1816->pch.channel);
diff --git a/sys/dev/sound/isa/ad1816.h b/sys/dev/sound/isa/ad1816.h
index e09f40d..b21d3cd 100644
--- a/sys/dev/sound/isa/ad1816.h
+++ b/sys/dev/sound/isa/ad1816.h
@@ -34,7 +34,7 @@
/* AD1816 register macros */
#define AD1816_ALE 0 /* indirect reg access */
-#define AD1816_INT 1 /* interupt status */
+#define AD1816_INT 1 /* interrupt status */
#define AD1816_LOW 2 /* indirect low byte */
#define AD1816_HIGH 3 /* indirect high byte */
diff --git a/sys/dev/sound/pci/atiixp.c b/sys/dev/sound/pci/atiixp.c
index 777e1b1..d1d01d7 100644
--- a/sys/dev/sound/pci/atiixp.c
+++ b/sys/dev/sound/pci/atiixp.c
@@ -902,7 +902,7 @@ atiixp_intr(void *p)
detected_codecs = status & CODEC_CHECK_BITS;
sc->codec_not_ready_bits |= detected_codecs;
- /* disable detected interupt sources */
+ /* disable detected interrupt sources */
enable = atiixp_rd(sc, ATI_REG_IER);
enable &= ~detected_codecs;
atiixp_wr(sc, ATI_REG_IER, enable);
diff --git a/sys/dev/sound/pci/emu10kx.c b/sys/dev/sound/pci/emu10kx.c
index 35af8aa..c2a8249 100644
--- a/sys/dev/sound/pci/emu10kx.c
+++ b/sys/dev/sound/pci/emu10kx.c
@@ -950,7 +950,7 @@ emu_intr_unregister(struct emu_sc_info *sc, int hnumber)
sc->ihandler[hnumber].softc = NULL;
sc->ihandler[hnumber].irq_func = NULL;
- /* other interupt handlers may use this INTE value */
+ /* other interrupt handlers may use this INTE value */
for (i = 0; i < EMU_MAX_IRQ_CONSUMERS; i++)
if (sc->ihandler[i].inte_mask != 0)
x |= sc->ihandler[i].inte_mask;
diff --git a/sys/dev/sound/pci/envy24.c b/sys/dev/sound/pci/envy24.c
index 136477b..e35b456 100644
--- a/sys/dev/sound/pci/envy24.c
+++ b/sys/dev/sound/pci/envy24.c
@@ -2461,7 +2461,7 @@ envy24_alloc_resource(struct sc_info *sc)
pci_read_config(sc->dev, PCIR_MT, 4));
#endif
- /* allocate interupt resource */
+ /* allocate interrupt resource */
sc->irqid = 0;
sc->irq = bus_alloc_resource(sc->dev, SYS_RES_IRQ, &sc->irqid,
0, ~0, 1, RF_ACTIVE | RF_SHAREABLE);
diff --git a/sys/dev/sound/pci/envy24ht.c b/sys/dev/sound/pci/envy24ht.c
index 4b08c0c..a3e4f36 100644
--- a/sys/dev/sound/pci/envy24ht.c
+++ b/sys/dev/sound/pci/envy24ht.c
@@ -2416,7 +2416,7 @@ envy24ht_alloc_resource(struct sc_info *sc)
pci_read_config(sc->dev, PCIR_MT, 4));
#endif
- /* allocate interupt resource */
+ /* allocate interrupt resource */
sc->irqid = 0;
sc->irq = bus_alloc_resource(sc->dev, SYS_RES_IRQ, &sc->irqid,
0, ~0, 1, RF_ACTIVE | RF_SHAREABLE);
diff --git a/sys/dev/sound/sbus/cs4231.c b/sys/dev/sound/sbus/cs4231.c
index 26e9301..a785f96 100644
--- a/sys/dev/sound/sbus/cs4231.c
+++ b/sys/dev/sound/sbus/cs4231.c
@@ -622,7 +622,7 @@ cs4231_power_reset(struct cs4231_softc *sc, int how)
/* turn on cs4231 mode */
cs4231_write(sc, CS_MISC_INFO,
cs4231_read(sc, CS_MISC_INFO) | CS_MODE2);
- /* enable interupts & clear CSR */
+ /* enable interrupts & clear CSR */
cs4231_write(sc, CS_PIN_CONTROL,
cs4231_read(sc, CS_PIN_CONTROL) | INTERRUPT_ENABLE);
CS_WRITE(sc, CS4231_STATUS, 0);
OpenPOWER on IntegriCloud
diff --git a/sys/dev/cm/smc90cx6.c b/sys/dev/cm/smc90cx6.c
index e8645ca..be0d871 100644
--- a/sys/dev/cm/smc90cx6.c
+++ b/sys/dev/cm/smc90cx6.c
@@ -592,7 +592,7 @@ cleanup:
sc->sc_rx_act = buffer;
sc->sc_intmask |= CM_RI;
/* this also clears the RI flag interupt: */
PUTREG(CMCMD, CM_RXBC(buffer));
PUTREG(CMSTAT, sc->sc_intmask);
@@ -779,7 +779,7 @@ cmintr(arg)
* configured sender)
*/
log(LOG_WARNING,
- "%s: spurious RX interupt or sender 0 "
+ "%s: spurious RX interrupt or sender 0 "
" (ignored)\n", ifp->if_xname);
/*
* restart receiver on same buffer.
@@ -797,7 +797,7 @@ cmintr(arg)
/*
* Start receiver on other receive
* buffer. This also clears the RI
- * interupt flag.
+ * interrupt flag.
*/
PUTREG(CMCMD, CM_RXBC(buffer));
/* in RX intr, so mask is ok for RX */
@@ -592,7 +592,7 @@ cleanup:
sc->sc_rx_act = buffer;
sc->sc_intmask |= CM_RI;
- /* this also clears the RI flag interupt: */
+ /* this also clears the RI flag interrupt: */
PUTREG(CMCMD, CM_RXBC(buffer));
PUTREG(CMSTAT, sc->sc_intmask);